@@ -42,8 +42,8 @@ class Features : public Module {
     Q_CLASSINFO("D-Bus Interface", "org.kde.ActivityManager.Features")
 
 public:
-    explicit Features(QObject *parent = Q_NULLPTR);
-    virtual ~Features();
+    explicit Features(QObject *parent = nullptr);
+    ~Features() override;
 
 public Q_SLOTS:
     /**
