@@ -26,10 +26,10 @@ class SlcPlugin : public Plugin {
     // Q_PLUGIN_METADATA(IID "org.kde.ActivityManager.plugins.slc")
 
 public:
-    explicit SlcPlugin(QObject *parent = Q_NULLPTR, const QVariantList &args = QVariantList());
-    ~SlcPlugin() Q_DECL_OVERRIDE;
+    explicit SlcPlugin(QObject *parent = nullptr, const QVariantList &args = QVariantList());
+    ~SlcPlugin() override;
 
-    bool init(QHash<QString, QObject *> &modules) Q_DECL_OVERRIDE;
+    bool init(QHash<QString, QObject *> &modules) override;
 
 private Q_SLOTS:
     void registeredResourceEvent(const Event &event);
